Package: rdocdump
Title: Dump 'R' Package Source, Documentation, and Vignettes into One
        File
Version: 0.3.0
Authors@R: 
    person("Egor", "Kotov", , "kotov.egor@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-6690-5345"))
Description: Dump source code, documentation and vignettes of an 'R'
    package into a single file. Supports installed packages, tar.gz
    archives, and package source directories. If the package is not
    installed, only its source is automatically downloaded from CRAN for
    processing. The output is a single plain text file or a character
    vector, which is useful to ingest complete package documentation and
    source into a large language model (LLM) or pass it further to other
    tools, such as 'ragnar' <https://github.com/tidyverse/ragnar> to
    create a Retrieval-Augmented Generation (RAG) workflow.
License: MIT + file LICENSE
URL: https://github.com/e-kotov/rdocdump,
        https://www.ekotov.pro/rdocdump/
BugReports: https://github.com/e-kotov/rdocdump/issues
Suggests: curl, pak, quarto, testthat (>= 3.0.0), withr
VignetteBuilder: quarto
Config/testthat/edition: 3
Encoding: UTF-8
Language: en
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-30 16:57:41 UTC; ek
Author: Egor Kotov [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-6690-5345>)
Maintainer: Egor Kotov <kotov.egor@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-30 17:10:02 UTC
Built: R 4.5.2; ; 2026-05-30 17:20:07 UTC; unix
