% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/util_cleanup_files.R
\name{cleanup_files}
\alias{cleanup_files}
\title{Cleanup Temporary Files}
\usage{
cleanup_files(pkg_info, keep_files)
}
\arguments{
\item{pkg_info}{A list returned by \code{resolve_pkg_path()}, containing \code{tar_path} and \code{extracted_path}.}

\item{keep_files}{A \code{character} value controlling whether temporary files should be kept.
Possible values are:
\itemize{
\item \code{"none"}: Delete both the tar.gz archive and the extracted files (default).
\item \code{"tgz"}: Keep only the tar.gz archive.
\item \code{"extracted"}: Keep only the extracted files.
\item \code{"both"}: Keep both the tar.gz archive and the extracted files.
}}
}
\value{
Invisibly returns \code{NULL}. If there are any issues with file deletion, warnings are issued.
}
\description{
Clean up temporary package archive and extracted files according to a keep_files policy.
}
\keyword{internal}
