% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/util_resolve_remote.R
\name{create_remote}
\alias{create_remote}
\title{Create Remote Object for remotes Package}
\usage{
create_remote(parsed)
}
\arguments{
\item{parsed}{Parsed reference from parse_remote_ref()}
}
\value{
Remote object suitable for remotes::remote_download()
}
\description{
Create Remote Object for remotes Package
}
\keyword{internal}
